'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-91a55b68.js');
const _commonjsHelpers = require('./_commonjsHelpers-0c557e26.js');

var eventemitter3 = _commonjsHelpers.createCommonjsModule(function (module) {

var has = Object.prototype.hasOwnProperty
  , prefix = '~';

/**
 * Constructor to create a storage for our `EE` objects.
 * An `Events` instance is a plain object whose properties are event names.
 *
 * @constructor
 * @private
 */
function Events() {}

//
// We try to not inherit from `Object.prototype`. In some engines creating an
// instance in this way is faster than calling `Object.create(null)` directly.
// If `Object.create(null)` is not supported we prefix the event names with a
// character to make sure that the built-in object properties are not
// overridden or used as an attack vector.
//
if (Object.create) {
  Events.prototype = Object.create(null);

  //
  // This hack is needed because the `__proto__` property is still inherited in
  // some old browsers like Android 4, iPhone 5.1, Opera 11 and Safari 5.
  //
  if (!new Events().__proto__) prefix = false;
}

/**
 * Representation of a single event listener.
 *
 * @param {Function} fn The listener function.
 * @param {*} context The context to invoke the listener with.
 * @param {Boolean} [once=false] Specify if the listener is a one-time listener.
 * @constructor
 * @private
 */
function EE(fn, context, once) {
  this.fn = fn;
  this.context = context;
  this.once = once || false;
}

/**
 * Add a listener for a given event.
 *
 * @param {EventEmitter} emitter Reference to the `EventEmitter` instance.
 * @param {(String|Symbol)} event The event name.
 * @param {Function} fn The listener function.
 * @param {*} context The context to invoke the listener with.
 * @param {Boolean} once Specify if the listener is a one-time listener.
 * @returns {EventEmitter}
 * @private
 */
function addListener(emitter, event, fn, context, once) {
  if (typeof fn !== 'function') {
    throw new TypeError('The listener must be a function');
  }

  var listener = new EE(fn, context || emitter, once)
    , evt = prefix ? prefix + event : event;

  if (!emitter._events[evt]) emitter._events[evt] = listener, emitter._eventsCount++;
  else if (!emitter._events[evt].fn) emitter._events[evt].push(listener);
  else emitter._events[evt] = [emitter._events[evt], listener];

  return emitter;
}

/**
 * Clear event by name.
 *
 * @param {EventEmitter} emitter Reference to the `EventEmitter` instance.
 * @param {(String|Symbol)} evt The Event name.
 * @private
 */
function clearEvent(emitter, evt) {
  if (--emitter._eventsCount === 0) emitter._events = new Events();
  else delete emitter._events[evt];
}

/**
 * Minimal `EventEmitter` interface that is molded against the Node.js
 * `EventEmitter` interface.
 *
 * @constructor
 * @public
 */
function EventEmitter() {
  this._events = new Events();
  this._eventsCount = 0;
}

/**
 * Return an array listing the events for which the emitter has registered
 * listeners.
 *
 * @returns {Array}
 * @public
 */
EventEmitter.prototype.eventNames = function eventNames() {
  var names = []
    , events
    , name;

  if (this._eventsCount === 0) return names;

  for (name in (events = this._events)) {
    if (has.call(events, name)) names.push(prefix ? name.slice(1) : name);
  }

  if (Object.getOwnPropertySymbols) {
    return names.concat(Object.getOwnPropertySymbols(events));
  }

  return names;
};

/**
 * Return the listeners registered for a given event.
 *
 * @param {(String|Symbol)} event The event name.
 * @returns {Array} The registered listeners.
 * @public
 */
EventEmitter.prototype.listeners = function listeners(event) {
  var evt = prefix ? prefix + event : event
    , handlers = this._events[evt];

  if (!handlers) return [];
  if (handlers.fn) return [handlers.fn];

  for (var i = 0, l = handlers.length, ee = new Array(l); i < l; i++) {
    ee[i] = handlers[i].fn;
  }

  return ee;
};

/**
 * Return the number of listeners listening to a given event.
 *
 * @param {(String|Symbol)} event The event name.
 * @returns {Number} The number of listeners.
 * @public
 */
EventEmitter.prototype.listenerCount = function listenerCount(event) {
  var evt = prefix ? prefix + event : event
    , listeners = this._events[evt];

  if (!listeners) return 0;
  if (listeners.fn) return 1;
  return listeners.length;
};

/**
 * Calls each of the listeners registered for a given event.
 *
 * @param {(String|Symbol)} event The event name.
 * @returns {Boolean} `true` if the event had listeners, else `false`.
 * @public
 */
EventEmitter.prototype.emit = function emit(event, a1, a2, a3, a4, a5) {
  var evt = prefix ? prefix + event : event;

  if (!this._events[evt]) return false;

  var listeners = this._events[evt]
    , len = arguments.length
    , args
    , i;

  if (listeners.fn) {
    if (listeners.once) this.removeListener(event, listeners.fn, undefined, true);

    switch (len) {
      case 1: return listeners.fn.call(listeners.context), true;
      case 2: return listeners.fn.call(listeners.context, a1), true;
      case 3: return listeners.fn.call(listeners.context, a1, a2), true;
      case 4: return listeners.fn.call(listeners.context, a1, a2, a3), true;
      case 5: return listeners.fn.call(listeners.context, a1, a2, a3, a4), true;
      case 6: return listeners.fn.call(listeners.context, a1, a2, a3, a4, a5), true;
    }

    for (i = 1, args = new Array(len -1); i < len; i++) {
      args[i - 1] = arguments[i];
    }

    listeners.fn.apply(listeners.context, args);
  } else {
    var length = listeners.length
      , j;

    for (i = 0; i < length; i++) {
      if (listeners[i].once) this.removeListener(event, listeners[i].fn, undefined, true);

      switch (len) {
        case 1: listeners[i].fn.call(listeners[i].context); break;
        case 2: listeners[i].fn.call(listeners[i].context, a1); break;
        case 3: listeners[i].fn.call(listeners[i].context, a1, a2); break;
        case 4: listeners[i].fn.call(listeners[i].context, a1, a2, a3); break;
        default:
          if (!args) for (j = 1, args = new Array(len -1); j < len; j++) {
            args[j - 1] = arguments[j];
          }

          listeners[i].fn.apply(listeners[i].context, args);
      }
    }
  }

  return true;
};

/**
 * Add a listener for a given event.
 *
 * @param {(String|Symbol)} event The event name.
 * @param {Function} fn The listener function.
 * @param {*} [context=this] The context to invoke the listener with.
 * @returns {EventEmitter} `this`.
 * @public
 */
EventEmitter.prototype.on = function on(event, fn, context) {
  return addListener(this, event, fn, context, false);
};

/**
 * Add a one-time listener for a given event.
 *
 * @param {(String|Symbol)} event The event name.
 * @param {Function} fn The listener function.
 * @param {*} [context=this] The context to invoke the listener with.
 * @returns {EventEmitter} `this`.
 * @public
 */
EventEmitter.prototype.once = function once(event, fn, context) {
  return addListener(this, event, fn, context, true);
};

/**
 * Remove the listeners of a given event.
 *
 * @param {(String|Symbol)} event The event name.
 * @param {Function} fn Only remove the listeners that match this function.
 * @param {*} context Only remove the listeners that have this context.
 * @param {Boolean} once Only remove one-time listeners.
 * @returns {EventEmitter} `this`.
 * @public
 */
EventEmitter.prototype.removeListener = function removeListener(event, fn, context, once) {
  var evt = prefix ? prefix + event : event;

  if (!this._events[evt]) return this;
  if (!fn) {
    clearEvent(this, evt);
    return this;
  }

  var listeners = this._events[evt];

  if (listeners.fn) {
    if (
      listeners.fn === fn &&
      (!once || listeners.once) &&
      (!context || listeners.context === context)
    ) {
      clearEvent(this, evt);
    }
  } else {
    for (var i = 0, events = [], length = listeners.length; i < length; i++) {
      if (
        listeners[i].fn !== fn ||
        (once && !listeners[i].once) ||
        (context && listeners[i].context !== context)
      ) {
        events.push(listeners[i]);
      }
    }

    //
    // Reset the array, or remove it completely if we have no more listeners.
    //
    if (events.length) this._events[evt] = events.length === 1 ? events[0] : events;
    else clearEvent(this, evt);
  }

  return this;
};

/**
 * Remove all listeners, or those of the specified event.
 *
 * @param {(String|Symbol)} [event] The event name.
 * @returns {EventEmitter} `this`.
 * @public
 */
EventEmitter.prototype.removeAllListeners = function removeAllListeners(event) {
  var evt;

  if (event) {
    evt = prefix ? prefix + event : event;
    if (this._events[evt]) clearEvent(this, evt);
  } else {
    this._events = new Events();
    this._eventsCount = 0;
  }

  return this;
};

//
// Alias methods names because people roll like that.
//
EventEmitter.prototype.off = EventEmitter.prototype.removeListener;
EventEmitter.prototype.addListener = EventEmitter.prototype.on;

//
// Expose the prefix.
//
EventEmitter.prefixed = prefix;

//
// Allow `EventEmitter` to be imported as module namespace.
//
EventEmitter.EventEmitter = EventEmitter;

//
// Expose the module.
//
{
  module.exports = EventEmitter;
}
});

class EventEmitter extends eventemitter3 {
  constructor() {
    super();
  }
  asObservable() {
    let listeners = [];
    let obserable = {
      on: (type, cb) => {
        listeners.push({ type, cb });
        this.on(type, cb);
        return obserable;
      },
      once: (type, cb) => {
        listeners.push({ type, cb });
        this.once(type, cb);
        return obserable;
      },
      removeListener: (type, cb) => {
        this.removeListener(type, cb);
        return obserable;
      },
      off: (type, cb) => {
        this.off(type, cb);
        return obserable;
      },
      removeAllListener() {
        listeners.forEach(({ type, cb }) => {
          this.off(type, cb);
        });
        listeners.length = 0;
        return obserable;
      },
      unsubscribe() {
        return obserable.removeAllListener();
      },
      reEmit(eventEmitter, eventNames) {
        for (let e of eventNames) {
          obserable.on(e, (...args) => {
            eventEmitter.emit(e, ...args);
          });
        }
        return obserable;
      }
    };
    return obserable;
  }
  reEmit(e, eventNames) {
    let obserable = e.asObservable();
    for (let e of eventNames) {
      obserable.on(e, (...args) => {
        this.emit(e, ...args);
      });
    }
    return obserable;
  }
}

class IframeMessenger extends EventEmitter {
  constructor(iframe) {
    super();
    this._iframe = iframe;
  }
  start() {
    this.stop();
    let onMessage = event => {
      if (event.origin === window.location.origin) {
        return;
      }
      // let data = JSON.parse(event.data);
      this.emit('message', {
        origin: event.origin,
        data: JSON.parse(event.data),
      });
    };
    window.addEventListener('message', onMessage, false);
    this._onMessage = onMessage;
  }
  stop() {
    window.removeEventListener('message', this._onMessage);
  }
  sendMessage(msg, targetOrigin = '*') {
    this._iframe.contentWindow.postMessage(JSON.stringify(msg), targetOrigin);
  }
}

// Unique ID creation requires a high quality random # generator. In the browser we therefore
// require the crypto API and do not support built-in fallback to lower quality random number
// generators (like Math.random()).
// getRandomValues needs to be invoked in a context where "this" is a Crypto implementation. Also,
// find the complete implementation of crypto (msCrypto) on IE11.
var getRandomValues = typeof crypto !== 'undefined' && crypto.getRandomValues && crypto.getRandomValues.bind(crypto) || typeof msCrypto !== 'undefined' && typeof msCrypto.getRandomValues === 'function' && msCrypto.getRandomValues.bind(msCrypto);
var rnds8 = new Uint8Array(16);
function rng() {
  if (!getRandomValues) {
    throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
  }

  return getRandomValues(rnds8);
}

const REGEX = /^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i;

function validate(uuid) {
  return typeof uuid === 'string' && REGEX.test(uuid);
}

/**
 * Convert array of 16 byte values to UUID string format of the form:
 * XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX
 */

var byteToHex = [];

for (var i = 0; i < 256; ++i) {
  byteToHex.push((i + 0x100).toString(16).substr(1));
}

function stringify(arr) {
  var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  // Note: Be careful editing this code!  It's been tuned for performance
  // and works in ways you may not expect. See https://github.com/uuidjs/uuid/pull/434
  var uuid = (byteToHex[arr[offset + 0]] + byteToHex[arr[offset + 1]] + byteToHex[arr[offset + 2]] + byteToHex[arr[offset + 3]] + '-' + byteToHex[arr[offset + 4]] + byteToHex[arr[offset + 5]] + '-' + byteToHex[arr[offset + 6]] + byteToHex[arr[offset + 7]] + '-' + byteToHex[arr[offset + 8]] + byteToHex[arr[offset + 9]] + '-' + byteToHex[arr[offset + 10]] + byteToHex[arr[offset + 11]] + byteToHex[arr[offset + 12]] + byteToHex[arr[offset + 13]] + byteToHex[arr[offset + 14]] + byteToHex[arr[offset + 15]]).toLowerCase(); // Consistency check for valid UUID.  If this throws, it's likely due to one
  // of the following:
  // - One or more input array values don't map to a hex octet (leading to
  // "undefined" in the uuid)
  // - Invalid input values for the RFC `version` or `variant` fields

  if (!validate(uuid)) {
    throw TypeError('Stringified UUID is invalid');
  }

  return uuid;
}

function v4(options, buf, offset) {
  options = options || {};
  var rnds = options.random || (options.rng || rng)(); // Per 4.4, set bits for version and `clock_seq_hi_and_reserved`

  rnds[6] = rnds[6] & 0x0f | 0x40;
  rnds[8] = rnds[8] & 0x3f | 0x80; // Copy bytes to buffer, if provided

  if (buf) {
    offset = offset || 0;

    for (var i = 0; i < 16; ++i) {
      buf[offset + i] = rnds[i];
    }

    return buf;
  }

  return stringify(rnds);
}

let instances = {};
class IframeSession extends EventEmitter {
  constructor(_sessionId, _origin, _iframeMessenger) {
    super();
    this._sessionId = _sessionId;
    this._origin = _origin;
    this._iframeMessenger = _iframeMessenger;
    this._listen();
  }
  static listen(iframeMessenger) {
    if (IframeSession.iframeObserable) {
      return;
    }
    IframeSession.iframeObserable = iframeMessenger
      .asObservable()
      .on('message', (msg) => {
      if (msg.data.resource !== 'iframe-session') {
        return;
      }
      let sessionId = '';
      switch (msg.data.method) {
        case 'init':
          sessionId = msg.data.params[0];
          newSession(sessionId, msg.origin);
          break;
      }
    });
    let newSession = (sessionId, origin) => {
      if (!instances[sessionId]) {
        let instance = new IframeSession(sessionId, origin, iframeMessenger);
        instances[sessionId] = instance;
        iframeMessenger.emit('new-session', instance);
      }
    };
  }
  _listen() {
    this._iframeObserable = this._iframeMessenger
      .asObservable()
      .on('message', (msg) => {
      if (msg.data.resource !== 'iframe-session') {
        return;
      }
      let sessionId = msg.data.params[0];
      if (sessionId !== this._sessionId) {
        return;
      }
      switch (msg.data.method) {
        case 'stop':
          delete instances[sessionId];
          this.destroy();
          break;
        case 'receive':
          this._receive(msg.data.params[1]);
          break;
      }
    });
  }
  static init(iframeMessenger) {
    let sessionId = v4();
    let session = new IframeSession(sessionId, '*', iframeMessenger);
    session._init();
    return session;
  }
  _receive(msg) {
    this.emit('message', msg);
  }
  _init() {
    this._iframeMessenger.sendMessage({
      resource: 'iframe-session',
      method: 'init',
      params: [this.sessionId],
    }, this._origin);
  }
  send(msg) {
    this._iframeMessenger.sendMessage({
      resource: 'iframe-session',
      method: 'receive',
      params: [this.sessionId, msg],
    }, this._origin);
  }
  get sessionId() {
    return this._sessionId;
  }
  destroy() {
    this.emit('destroy');
    this.removeAllListeners();
    this._iframeObserable.unsubscribe();
    this._iframeMessenger = null;
  }
}

const quickomChatIframeCss = "quickom-chat-iframe{}quickom-chat-iframe iframe{border:1px solid #ebeef5;border-top-right-radius:10px;border-top-left-radius:10px;-webkit-box-shadow:0 2px 12px 0 rgba(0,0,0,.1);box-shadow:0 2px 12px 0 rgba(0,0,0,.1)}";

const QuickomChatIframe = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.visible = index.createEvent(this, "visible", 7);
    this.domain = 'https://quickom-widget.web.app';
    this.memberId = '';
    this.chatWithMemberId = '';
    this.avatar = '';
    this.apiKey = '';
    this.iframeElement = null;
    this.iframeMessenger = null;
    this.iframeSession = null;
  }
  getUrl() {
    return `${this.domain}/chat`;
  }
  onIframeRef(el) {
    this.iframeElement = el;
  }
  onLoadIframe() {
    this.iframeMessenger = new IframeMessenger(this.iframeElement);
    this.iframeMessenger.start();
    this.iframeSession = IframeSession.init(this.iframeMessenger);
    this.sendChatWithMember();
    this.iframeSession.on('message', this.onChatBoxMessage.bind(this));
  }
  sendChatWithMember() {
    if (this.iframeSession && this.memberId && this.chatWithMemberId && this.apiKey) {
      this.iframeSession.send({
        resource: 'chat',
        method: 'chatWithMember',
        params: [{ memberId: this.memberId, chatWithMemberId: this.chatWithMemberId, apiKey: this.apiKey, avatar: this.avatar }],
      });
    }
  }
  onChatBoxMessage(data) {
    switch (data.method) {
      case 'show':
        this.visible.emit(true);
        break;
      case 'hide':
        this.visible.emit(false);
        break;
    }
  }
  render() {
    return index.h("iframe", { class: "relative", onLoad: () => this.onLoadIframe(), ref: el => this.onIframeRef(el), src: this.getUrl(), width: "100%", height: "100%", frameborder: "0" });
  }
  onChangeMemberId() {
    this.sendChatWithMember();
  }
  onChangeChatWithMemberId() {
    this.sendChatWithMember();
  }
  onChangeApiKey() {
    this.sendChatWithMember();
  }
  disconnectedCallback() {
    this.iframeSession.destroy();
    this.iframeMessenger.stop();
    this.iframeMessenger = null;
    this.iframeSession = null;
  }
  static get watchers() { return {
    "memberId": ["onChangeMemberId", "onChangeChatWithMemberId"],
    "apiKey": ["onChangeApiKey"]
  }; }
};
QuickomChatIframe.style = quickomChatIframeCss;

var plainDraggable_min = _commonjsHelpers.createCommonjsModule(function (module, exports) {
var parcelRequire = undefined;
parcelRequire=function(e,r,t,n){var i,o="function"==typeof parcelRequire&&parcelRequire,u="function"==typeof _commonjsHelpers.commonjsRequire&&_commonjsHelpers.commonjsRequire;function f(t,n){if(!r[t]){if(!e[t]){var i="function"==typeof parcelRequire&&parcelRequire;if(!n&&i)return i(t,!0);if(o)return o(t,!0);if(u&&"string"==typeof t)return u(t);var c=new Error("Cannot find module '"+t+"'");throw c.code="MODULE_NOT_FOUND",c}p.resolve=function(r){return e[t][1][r]||r},p.cache={};var l=r[t]=new f.Module(t);e[t][0].call(l.exports,p,l,l.exports,this);}return r[t].exports;function p(e){return f(p.resolve(e))}}f.isParcelRequire=!0,f.Module=function(e){this.id=e,this.bundle=f,this.exports={};},f.modules=e,f.cache=r,f.parent=o,f.register=function(r,t){e[r]=[function(e,r){r.exports=t;},{}];};for(var c=0;c<t.length;c++)try{f(t[c]);}catch(e){i||(i=e);}if(t.length){var l=f(t[t.length-1]);module.exports=l;}if(parcelRequire=f,i)throw i;return f}({"kohH":[function(require,module,exports) {
Object.defineProperty(exports,"__esModule",{value:!0}),exports.default=void 0;var n=1e3/60,e=500,i=[],t=window.requestAnimationFrame||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||window.msRequestAnimationFrame||function(e){return setTimeout(e,n)},o=window.cancelAnimationFrame||window.mozCancelAnimationFrame||window.webkitCancelAnimationFrame||window.msCancelAnimationFrame||function(n){return clearTimeout(n)},a=Date.now(),r=void 0;function u(){var n=void 0,l=void 0;r&&(o.call(window,r),r=null),i.forEach(function(e){var i;(i=e.event)&&(e.event=null,e.listener(i),n=!0);}),n?(a=Date.now(),l=!0):Date.now()-a<e&&(l=!0),l&&(r=t.call(window,u));}function l(n){var e=-1;return i.some(function(i,t){return i.listener===n&&(e=t,!0)}),e}var w={add:function(n){var e=void 0;return -1===l(n)?(i.push(e={listener:n}),function(n){e.event=n,r||u();}):null},remove:function(n){var e;(e=l(n))>-1&&(i.splice(e,1),!i.length&&r&&(o.call(window,r),r=null));}},m=w;exports.default=m;
},{}],"cjFF":[function(require,module,exports) {
Object.defineProperty(exports,"__esModule",{value:!0}),exports.default=void 0;var t=e(require("anim-event"));function e(t){return t&&t.__esModule?t:{default:t}}var n=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r);}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}();function r(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}var a=400,o=!1;try{window.addEventListener("test",null,Object.defineProperty({},"passive",{get:function(){o=!0;}}));}catch(h){}function i(t,e,n,r){t.addEventListener(e,n,o?r:r.capture);}function u(t,e){if(null!=t&&null!=e)for(var n=0;n<t.length;n++)if(t[n].identifier===e)return t[n];return null}function s(t){return t&&"number"==typeof t.clientX&&"number"==typeof t.clientY}function l(t){t.preventDefault();}var c=function(){function e(t){var n=this;r(this,e),this.startHandlers={},this.lastHandlerId=0,this.curPointerClass=null,this.curTouchId=null,this.lastPointerXY={clientX:0,clientY:0},this.lastTouchTime=0,this.options={preventDefault:!0,stopPropagation:!0},t&&["preventDefault","stopPropagation"].forEach(function(e){"boolean"==typeof t[e]&&(n.options[e]=t[e]);});}return n(e,[{key:"regStartHandler",value:function(t){var e=this;return e.startHandlers[++e.lastHandlerId]=function(n){var r="mousedown"===n.type?"mouse":"touch",o=Date.now(),i=void 0,u=void 0;if("touch"===r)e.lastTouchTime=o,i=n.changedTouches[0],u=n.changedTouches[0].identifier;else {if(o-e.lastTouchTime<a)return;i=n;}if(!s(i))throw new Error("No clientX/clientY");e.curPointerClass&&e.cancel(),t.call(e,i)&&(e.curPointerClass=r,e.curTouchId="touch"===r?u:null,e.lastPointerXY.clientX=i.clientX,e.lastPointerXY.clientY=i.clientY,e.options.preventDefault&&n.preventDefault(),e.options.stopPropagation&&n.stopPropagation());},e.lastHandlerId}},{key:"unregStartHandler",value:function(t){delete this.startHandlers[t];}},{key:"addStartHandler",value:function(t,e){if(!this.startHandlers[e])throw new Error("Invalid handlerId: "+e);return i(t,"mousedown",this.startHandlers[e],{capture:!1,passive:!1}),i(t,"touchstart",this.startHandlers[e],{capture:!1,passive:!1}),i(t,"dragstart",l,{capture:!1,passive:!1}),e}},{key:"removeStartHandler",value:function(t,e){if(!this.startHandlers[e])throw new Error("Invalid handlerId: "+e);return t.removeEventListener("mousedown",this.startHandlers[e],!1),t.removeEventListener("touchstart",this.startHandlers[e],!1),t.removeEventListener("dragstart",l,!1),e}},{key:"addMoveHandler",value:function(e,n){var r=this,a=t.default.add(function(t){var e="mousemove"===t.type?"mouse":"touch";if("touch"===e&&(r.lastTouchTime=Date.now()),e===r.curPointerClass){var n="touch"===e?u(t.changedTouches,r.curTouchId):t;s(n)&&(n.clientX===r.lastPointerXY.clientX&&n.clientY===r.lastPointerXY.clientY||r.move(n),r.options.preventDefault&&t.preventDefault(),r.options.stopPropagation&&t.stopPropagation());}});i(e,"mousemove",a,{capture:!1,passive:!1}),i(e,"touchmove",a,{capture:!1,passive:!1}),r.curMoveHandler=n;}},{key:"move",value:function(t){s(t)&&(this.lastPointerXY.clientX=t.clientX,this.lastPointerXY.clientY=t.clientY),this.curMoveHandler&&this.curMoveHandler(this.lastPointerXY);}},{key:"addEndHandler",value:function(t,e){var n=this;function r(t){var e="mouseup"===t.type?"mouse":"touch";if("touch"===e&&(n.lastTouchTime=Date.now()),e===n.curPointerClass){var r="touch"===e?u(t.changedTouches,n.curTouchId)||(u(t.touches,n.curTouchId)?null:{}):t;r&&(n.end(r),n.options.preventDefault&&t.preventDefault(),n.options.stopPropagation&&t.stopPropagation());}}i(t,"mouseup",r,{capture:!1,passive:!1}),i(t,"touchend",r,{capture:!1,passive:!1}),n.curEndHandler=e;}},{key:"end",value:function(t){s(t)&&(this.lastPointerXY.clientX=t.clientX,this.lastPointerXY.clientY=t.clientY),this.curEndHandler&&this.curEndHandler(this.lastPointerXY),this.curPointerClass=this.curTouchId=null;}},{key:"addCancelHandler",value:function(t,e){var n=this;i(t,"touchcancel",function(t){n.lastTouchTime=Date.now(),null!=n.curPointerClass&&(u(t.changedTouches,n.curTouchId)||!u(t.touches,n.curTouchId))&&n.cancel();},{capture:!1,passive:!1}),n.curCancelHandler=e;}},{key:"cancel",value:function(){this.curCancelHandler&&this.curCancelHandler(),this.curPointerClass=this.curTouchId=null;}}],[{key:"addEventListenerWithOptions",get:function(){return i}}]),e}(),d=c;exports.default=d;
},{"anim-event":"kohH"}],"Fo6c":[function(require,module,exports) {
function e(e){return e.substr(0,1).toUpperCase()+e.substr(1)}Object.defineProperty(exports,"__esModule",{value:!0}),exports.default=void 0;var r=["webkit","moz","ms","o"],t=r.reduce(function(r,t){return r.push(t),r.push(e(t)),r},[]),n=r.map(function(e){return "-"+e+"-"}),u=function(){var e=void 0;return function(){return e=e||document.createElement("div").style}}(),o=function(){var e=new RegExp("^(?:"+r.join("|")+")(.)","i"),t=/[A-Z]/;return function(r){return "float"===(r=(r+"").replace(/\s/g,"").replace(/-([\da-z])/gi,function(e,r){return r.toUpperCase()}).replace(e,function(e,r){return t.test(r)?r.toLowerCase():e})).toLowerCase()?"cssFloat":r}}(),i=function(){var e=new RegExp("^(?:"+n.join("|")+")","i");return function(r){return (null!=r?r+"":"").replace(/\s/g,"").replace(e,"")}}(),a=function(e,r){var t=u();return e=e.replace(/[A-Z]/g,function(e){return "-"+e.toLowerCase()}),t.setProperty(e,r),null!=t[e]&&t.getPropertyValue(e)===r},s={},c={};function l(r){if((r=o(r))&&null==s[r]){var n=u();if(null!=n[r])s[r]=r;else {var i=e(r);t.some(function(e){var t=e+i;return null!=n[t]&&(s[r]=t,!0)})||(s[r]=!1);}}return s[r]||void 0}function f(e,r){var t=void 0;return (e=l(e))?(c[e]=c[e]||{},(Array.isArray(r)?r:[r]).some(function(r){return r=i(r),null!=c[e][r]?!1!==c[e][r]&&(t=c[e][r],!0):a(e,r)?(t=c[e][r]=r,!0):!!n.some(function(n){var u=n+r;return !!a(e,u)&&(t=c[e][r]=u,!0)})||(c[e][r]=!1,!1)}),"string"==typeof t?t:void 0):t}var p={getName:l,getValue:f},v=p;exports.default=v;
},{}],"O69e":[function(require,module,exports) {
function t(t){return (t+"").trim()}function n(t,n){n.setAttribute("class",t.join(" "));}function e(e,i,r){r.filter(function(n){return !(!(n=t(n))||-1!==e.indexOf(n))&&(e.push(n),!0)}).length&&n(e,i);}function i(e,i,r){r.filter(function(n){var i=void 0;return !(!(n=t(n))||-1===(i=e.indexOf(n)))&&(e.splice(i,1),!0)}).length&&n(e,i);}function r(e,i,r,o){var u=e.indexOf(r=t(r));return -1!==u?!!o||(e.splice(u,1),n(e,i),!1):!1!==o&&(e.push(r),n(e,i),!0)}function o(e,i,r,o){var u=void 0;(r=t(r))&&(o=t(o))&&r!==o&&-1!==(u=e.indexOf(r))&&(e.splice(u,1),-1===e.indexOf(o)&&e.push(o),n(e,i));}function u(n){return !u.ignoreNative&&n.classList||(c=(n.getAttribute("class")||"").trim().split(/\s+/).filter(function(t){return !!t}),f={length:c.length,item:function(t){return c[t]},contains:function(n){return -1!==c.indexOf(t(n))},add:function(){return e(c,n,Array.prototype.slice.call(arguments)),u.methodChain?f:void 0},remove:function(){return i(c,n,Array.prototype.slice.call(arguments)),u.methodChain?f:void 0},toggle:function(t,e){return r(c,n,t,e)},replace:function(t,e){return o(c,n,t,e),u.methodChain?f:void 0}});var c,f;}Object.defineProperty(exports,"__esModule",{value:!0}),exports.default=void 0,u.methodChain=!0;var c=u;exports.default=c;
},{}],"tHsO":[function(require,module,exports) {
function t(e){return (t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(e)}var e=this&&this.__importDefault||function(t){return t&&t.__esModule?t:{default:t}};Object.defineProperty(exports,"__esModule",{value:!0});var n=e(require("pointer-event")),r=e(require("cssprefix")),o=e(require("anim-event")),i=e(require("m-class-list"));i.default.ignoreNative=!0;var a,l,s,d,u,f,c,p,g,m,y,h,v,x=9e3,b=20,S="tl",w="both",E="both",B="containment",O=["tl","tr","bl","br"],T=["start","end"],C=["inside","outside"],_=[40,200,1e3],j=[100,40,0],I="-ms-scroll-limit"in document.documentElement.style&&"-ms-ime-align"in document.documentElement.style&&!window.navigator.msPointerEnabled,P=!I&&!!document.uniqueID,W="MozAppearance"in document.documentElement.style,L=!(I||W||!window.chrome||!window.CSS),D=!I&&!P&&!W&&!L&&!window.chrome&&"WebkitAppearance"in document.documentElement.style,F=function(){var t={}.toString,e={}.hasOwnProperty.toString,n=e.call(Object);return function(r){var o,i;return r&&"[object Object]"===t.call(r)&&(!(o=Object.getPrototypeOf(r))||(i=o.hasOwnProperty("constructor")&&o.constructor)&&"function"==typeof i&&e.call(i)===n)}}(),H=Number.isFinite||function(t){return "number"==typeof t&&window.isFinite(t)},R={},A={},z=new n.default,M=0,X=D?["all-scroll","move"]:["grab","all-scroll","move"],Y=D?"move":["grabbing","move"],V="plain-draggable",N="plain-draggable-dragging",G="plain-draggable-moving",k={},q=1e3/60,U=window.requestAnimationFrame||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||window.msRequestAnimationFrame||function(t){return setTimeout(t,q)},Z=window.cancelAnimationFrame||window.mozCancelAnimationFrame||window.webkitCancelAnimationFrame||window.msCancelAnimationFrame||function(t){return clearTimeout(t)},$=function(){var t=Date.now();["x","y"].forEach(function(e){var n=K[e];if(n){var r=t-n.lastFrameTime,o=h(y,e),i=null!=n.lastValue&&Math.abs(n.lastValue-o)<10?n.lastValue:o;if(-1===n.dir?i>n.min:i<n.max){var a=i+n.speed*r*n.dir;a<n.min?a=n.min:a>n.max&&(a=n.max),h(y,e,a),n.lastValue=a;}n.lastFrameTime=t;}});},J=function t(){Z.call(window,v),$(),v=U.call(window,t);},K={};function Q(t,e,n){return void 0===n&&(n=null),null!=n&&("x"===e?t.scrollTo(n,t.pageYOffset):t.scrollTo(t.pageXOffset,n)),"x"===e?t.pageXOffset:t.pageYOffset}function tt(t,e,n){void 0===n&&(n=null);var r="x"===e?"scrollLeft":"scrollTop";return null!=n&&(t[r]=n),t[r]}function et(t,e,n){var r,o,i,a,l={};a=e?document.documentElement:t,l.clientWidth=a.clientWidth,l.clientHeight=a.clientHeight;var s,d=0,u=0;if(!n){var f=void 0,c=void 0;e?(f=Q(t,"x"),c=Q(t,"y"),r=getComputedStyle(document.documentElement,""),o=getComputedStyle(document.body,""),d=Q(t,"x",document.documentElement.scrollWidth+l.clientWidth+["marginLeft","marginRight","borderLeftWidth","borderRightWidth","paddingLeft","paddingRight"].reduce(function(t,e){return t+(parseFloat(r[e])||0)+(parseFloat(o[e])||0)},0)),u=Q(t,"y",document.documentElement.scrollHeight+l.clientHeight+["marginTop","marginBottom","borderTopWidth","borderBottomWidth","paddingTop","paddingBottom"].reduce(function(t,e){return t+(parseFloat(r[e])||0)+(parseFloat(o[e])||0)},0)),Q(t,"x",f),Q(t,"y",c)):(f=tt(t,"x"),c=tt(t,"y"),i=getComputedStyle(t,""),d=tt(t,"x",t.scrollWidth+l.clientWidth+["marginLeft","marginRight","borderLeftWidth","borderRightWidth","paddingLeft","paddingRight"].reduce(function(t,e){return t+(parseFloat(i[e])||0)},0)),u=tt(t,"y",t.scrollHeight+l.clientHeight+["marginTop","marginBottom","borderTopWidth","borderBottomWidth","paddingTop","paddingBottom"].reduce(function(t,e){return t+(parseFloat(i[e])||0)},0)),tt(t,"x",f),tt(t,"y",c));}return l.scrollWidth=l.clientWidth+d,l.scrollHeight=l.clientHeight+u,e?l.clientX=l.clientY=0:(s=t.getBoundingClientRect(),i||(i=getComputedStyle(t,"")),l.clientX=s.left+(parseFloat(i.borderLeftWidth)||0),l.clientY=s.top+(parseFloat(i.borderTopWidth)||0)),l}function nt(t){return t?F(t)?Object.keys(t).reduce(function(e,n){return e[n]=nt(t[n]),e},{}):Array.isArray(t)?t.map(nt):t:t}function rt(e,n){var r,o;return t(e)!==t(n)||(r=F(e)?"obj":Array.isArray(e)?"array":"")!=(F(n)?"obj":Array.isArray(n)?"array":"")||("obj"===r?rt(o=Object.keys(e).sort(),Object.keys(n).sort())||o.some(function(t){return rt(e[t],n[t])}):"array"===r?e.length!==n.length||e.some(function(t,e){return rt(t,n[e])}):e!==n)}function ot(t){return !(!t||t.nodeType!==Node.ELEMENT_NODE||"function"!=typeof t.getBoundingClientRect||t.compareDocumentPosition(document)&Node.DOCUMENT_POSITION_DISCONNECTED)}function it(t){if(!F(t))return null;var e;if(!H(e=t.left)&&!H(e=t.x))return null;if(t.left=t.x=e,!H(e=t.top)&&!H(e=t.y))return null;if(t.top=t.y=e,H(t.width)&&t.width>=0)t.right=t.left+t.width;else {if(!(H(t.right)&&t.right>=t.left))return null;t.width=t.right-t.left;}if(H(t.height)&&t.height>=0)t.bottom=t.top+t.height;else {if(!(H(t.bottom)&&t.bottom>=t.top))return null;t.height=t.bottom-t.top;}return t}function at(t){return H(t)?{value:t,isRatio:!1}:"string"==typeof t?function(t){var e,n,r=/^(.+?)(%)?$/.exec(t);return r&&H(e=parseFloat(r[1]))?{value:(n=!(!r[2]||!e))?e/100:e,isRatio:n}:null}(t.replace(/\s/g,"")):null}function lt(t){return t.isRatio?100*t.value+"%":t.value}function st(t,e,n){return "number"==typeof t?t:e+t.value*(t.isRatio?n:1)}function dt(t){if(!F(t))return null;var e;if(!(e=at(t.left))&&!(e=at(t.x)))return null;if(t.left=t.x=e,!(e=at(t.top))&&!(e=at(t.y)))return null;if(t.top=t.y=e,(e=at(t.width))&&e.value>=0)t.width=e,delete t.right;else {if(!(e=at(t.right)))return null;t.right=e,delete t.width;}if((e=at(t.height))&&e.value>=0)t.height=e,delete t.bottom;else {if(!(e=at(t.bottom)))return null;t.bottom=e,delete t.height;}return t}function ut(t){return Object.keys(t).reduce(function(e,n){return e[n]=lt(t[n]),e},{})}function ft(t,e){var n={left:"x",right:"x",x:"x",width:"x",top:"y",bottom:"y",y:"y",height:"y"},r={x:e.left,y:e.top},o={x:e.width,y:e.height};return it(Object.keys(t).reduce(function(e,i){return e[i]=st(t[i],"width"===i||"height"===i?0:r[n[i]],o[n[i]]),e},{}))}function ct(t,e){void 0===e&&(e=null);var n=t.getBoundingClientRect(),r={left:n.left,top:n.top,width:n.width,height:n.height};if(r.left+=window.pageXOffset,r.top+=window.pageYOffset,e){var o=window.getComputedStyle(t,""),i=parseFloat(o.borderTopWidth)||0,a=parseFloat(o.borderRightWidth)||0,l=parseFloat(o.borderBottomWidth)||0,s=parseFloat(o.borderLeftWidth)||0;r.left+=s,r.top+=i,r.width-=s+a,r.height-=i+l;}return it(r)}function pt(t,e){var n=t.style;n.webkitTapHighlightColor="transparent";var o=r.default.getName("boxShadow"),i=window.getComputedStyle(t,"")[o];return i&&"none"!==i||(n[o]="0 0 1px transparent"),e&&p&&(n[p]="translateZ(0)"),t}function gt(t,e){null==d&&(!1!==X&&(d=r.default.getValue("cursor",X)),null==d&&(d=!1)),t.style.cursor=!1===d?e:d;}function mt(t){null==u&&(!1!==Y&&(u=r.default.getValue("cursor",Y)),null==u&&(u=!1)),!1!==u&&(t.style.cursor=u);}function yt(t,e,n){var r=t.svgPoint;return r.x=e,r.y=n,r.matrixTransform(t.svgCtmElement.getScreenCTM().inverse())}function ht(t,e){var n=t.elementBBox;if(e.left!==n.left||e.top!==n.top){var r=t.htmlOffset;return t.elementStyle[p]="translate("+(e.left+r.left)+"px, "+(e.top+r.top)+"px)",!0}return !1}function vt(t,e){var n=t.elementBBox,r=t.elementStyle,o=t.htmlOffset,i=!1;return e.left!==n.left&&(r.left=e.left+o.left+"px",i=!0),e.top!==n.top&&(r.top=e.top+o.top+"px",i=!0),i}function xt(t,e){var n=t.elementBBox;if(e.left!==n.left||e.top!==n.top){var r=t.svgOffset,o=t.svgOriginBBox,i=yt(t,e.left-window.pageXOffset,e.top-window.pageYOffset);return t.svgTransform.setTranslate(i.x+r.x-o.x,i.y+r.y-o.y),!0}return !1}function bt(t,e,n){void 0===n&&(n=null);var r=t.elementBBox;function o(){t.minLeft>=t.maxLeft?e.left=r.left:e.left<t.minLeft?e.left=t.minLeft:e.left>t.maxLeft&&(e.left=t.maxLeft),t.minTop>=t.maxTop?e.top=r.top:e.top<t.minTop?e.top=t.minTop:e.top>t.maxTop&&(e.top=t.maxTop);}if(o(),n){if(!1===n(e))return !1;o();}var i=t.moveElm(t,e);return i&&(t.elementBBox=it({left:e.left,top:e.top,width:r.width,height:r.height})),i}function St(t){var e=t.element,n=t.elementStyle,r=ct(e),o=["display","marginTop","marginBottom","width","height"];o.unshift(p);var i=n[c];n[c]="none";var a=ct(e);t.orgStyle?o.forEach(function(e){null!=t.lastStyle[e]&&n[e]!==t.lastStyle[e]||(n[e]=t.orgStyle[e]);}):(t.orgStyle=o.reduce(function(t,e){return t[e]=n[e]||"",t},{}),t.lastStyle={});var l=ct(e),s=window.getComputedStyle(e,"");"inline"===s.display&&(n.display="inline-block",["Top","Bottom"].forEach(function(t){var e=parseFloat(s["padding"+t]);n["margin"+t]=e?"-"+e+"px":"0";})),n[p]="translate(0, 0)";var d=ct(e),u=t.htmlOffset={left:d.left?-d.left:0,top:d.top?-d.top:0};return n[p]="translate("+(r.left+u.left)+"px, "+(r.top+u.top)+"px)",["width","height"].forEach(function(r){d[r]!==l[r]&&(n[r]=l[r]+"px",(d=ct(e))[r]!==l[r]&&(n[r]=l[r]-(d[r]-l[r])+"px")),t.lastStyle[r]=n[r];}),n[c]=i,a.left===r.left&&a.top===r.top||(n[p]="translate("+(a.left+u.left)+"px, "+(a.top+u.top)+"px)"),a}function wt(t){var e=t.element,n=t.elementStyle,r=ct(e),o=["position","marginTop","marginRight","marginBottom","marginLeft","width","height"],i=n[c];n[c]="none";var a=ct(e);t.orgStyle?o.forEach(function(e){null!=t.lastStyle[e]&&n[e]!==t.lastStyle[e]||(n[e]=t.orgStyle[e]);}):(t.orgStyle=o.reduce(function(t,e){return t[e]=n[e]||"",t},{}),t.lastStyle={});var l=ct(e);n.position="absolute",n.left=n.top=n.margin="0";var s=ct(e),d=t.htmlOffset={left:s.left?-s.left:0,top:s.top?-s.top:0};return n.left=r.left+d.left+"px",n.top=r.top+d.top+"px",["width","height"].forEach(function(r){s[r]!==l[r]&&(n[r]=l[r]+"px",(s=ct(e))[r]!==l[r]&&(n[r]=l[r]-(s[r]-l[r])+"px")),t.lastStyle[r]=n[r];}),n[c]=i,a.left===r.left&&a.top===r.top||(n.left=a.left+d.left+"px",n.top=a.top+d.top+"px"),a}function Et(t){var e=t.element,n=t.svgTransform,r=e.getBoundingClientRect(),o=ct(e);n.setTranslate(0,0);var i=t.svgOriginBBox=e.getBBox(),a=e.getBoundingClientRect(),l=yt(t,a.left,a.top),s=t.svgOffset={x:i.x-l.x,y:i.y-l.y},d=yt(t,r.left,r.top);return n.setTranslate(d.x+s.x-i.x,d.y+s.y-i.y),o}function Bt(t,e){void 0===e&&(e="");var n=ct(document.documentElement),r=t.elementBBox=t.initElm(t),o=t.containmentBBox=t.containmentIsBBox?ft(t.options.containment,n)||n:ct(t.options.containment,!0);if(t.minLeft=o.left,t.maxLeft=o.right-r.width,t.minTop=o.top,t.maxTop=o.bottom-r.height,bt(t,{left:r.left,top:r.top}),t.parsedSnapTargets){var i={x:r.width,y:r.height},a={x:t.minLeft,y:t.minTop},l={x:t.maxLeft,y:t.maxTop},s={left:"x",right:"x",x:"x",width:"x",xStart:"x",xEnd:"x",xStep:"x",top:"y",bottom:"y",y:"y",height:"y",yStart:"y",yEnd:"y",yStep:"y"},d=t.parsedSnapTargets.reduce(function(t,e){var d,u="containment"===e.base?o:n,f={x:u.left,y:u.top},c={x:u.width,y:u.height};function p(n){if(null==n.center&&(n.center=e.center),null==n.xGravity&&(n.xGravity=e.gravity),null==n.yGravity&&(n.yGravity=e.gravity),null!=n.x&&null!=n.y)n.x=st(n.x,f.x,c.x),n.y=st(n.y,f.y,c.y),n.center&&(n.x-=i.x/2,n.y-=i.y/2,n.corners=["tl"]),(n.corners||e.corners).forEach(function(e){var r=n.x-("tr"===e||"br"===e?i.x:0),o=n.y-("bl"===e||"br"===e?i.y:0);if(r>=a.x&&r<=l.x&&o>=a.y&&o<=l.y){var s={x:r,y:o},d=r-n.xGravity,u=r+n.xGravity,f=o-n.yGravity,c=o+n.yGravity;d>a.x&&(s.gravityXStart=d),u<l.x&&(s.gravityXEnd=u),f>a.y&&(s.gravityYStart=f),c<l.y&&(s.gravityYEnd=c),t.push(s);}});else {var r=null!=n.x?"x":"y",o="x"===r?"y":"x",s=o+"Start",d=o+"End",u=r+"Gravity",p=r.toUpperCase(),g=o.toUpperCase(),m="gravity"+p+"Start",y="gravity"+p+"End",h="gravity"+g+"Start",v="gravity"+g+"End";if(n[r]=st(n[r],f[r],c[r]),n[s]=st(n[s],f[o],c[o]),n[d]=st(n[d],f[o],c[o])-i[o],n[s]>n[d]||n[s]>l[o]||n[d]<a[o])return;n.center&&(n[r]-=i[r]/2,n.sides=["start"]),(n.sides||e.sides).forEach(function(e){var f=n[r]-("end"===e?i[r]:0);if(f>=a[r]&&f<=l[r]){var c={},p=f-n[u],g=f+n[u];c[r]=f,p>a[r]&&(c[m]=p),g<l[r]&&(c[y]=g),n[s]>a[o]&&(c[h]=n[s]),n[d]<l[o]&&(c[v]=n[d]),t.push(c);}});}}if((d=e.element?ct(e.element):null)||e.ppBBox)e.ppBBox&&(d=ft(e.ppBBox,u)),d&&e.edges.forEach(function(t){var n=e.gravity,o=e.gravity;"outside"===t&&(n+=r.width,o+=r.height);var i=d.left-n,a=d.right+n,l=d.top-o,s=d.bottom+o,u="inside"===t?"start":"end";p({xStart:i,xEnd:a,y:d.top,sides:[u],center:!1}),p({x:d.left,yStart:l,yEnd:s,sides:[u],center:!1}),u="inside"===t?"end":"start",p({xStart:i,xEnd:a,y:d.bottom,sides:[u],center:!1}),p({x:d.right,yStart:l,yEnd:s,sides:[u],center:!1});});else {var g=[["x","y","xStart","xEnd","xStep","yStart","yEnd","yStep"].reduce(function(t,n){return e[n]&&(t[n]=st(e[n],"xStep"===n||"yStep"===n?0:f[s[n]],c[s[n]])),t},{})];["x","y"].forEach(function(t){var n=t+"Start",r=t+"End",o=t+"Step",i=t+"Gravity";g=g.reduce(function(a,l){var s=l[n],d=l[r],u=l[o];if(null!=s&&null!=d&&s>=d)return a;if(null!=u){if(u<2)return a;var f=u/2;f=e.gravity>f?f:null;for(var c=s;c<=d;c+=u){var p=Object.keys(l).reduce(function(t,e){return e!==n&&e!==r&&e!==o&&(t[e]=l[e]),t},{});p[t]=c,p[i]=f,a.push(p);}}else a.push(l);return a},[]);}),g.forEach(function(t){p(t);});}return t},[]);t.snapTargets=d.length?d:null;}var u={},f=t.options.autoScroll;if(f){u.isWindow=f.target===window,u.target=f.target;var c="scroll"===e,p=et(f.target,u.isWindow,c),g=it({left:p.clientX,top:p.clientY,width:p.clientWidth,height:p.clientHeight});u.scrollableBBox=g,c?t.autoScroll&&(u.scrollWidth=t.autoScroll.scrollWidth,u.scrollHeight=t.autoScroll.scrollHeight):(u.scrollWidth=p.scrollWidth,u.scrollHeight=p.scrollHeight),[["X","Width","left","right"],["Y","Height","top","bottom"]].forEach(function(t){var e=t[0],n=t[1],o=t[2],i=t[3],a=(u["scroll"+n]||0)-p["client"+n],l=f["min"+e]||0,s=H(f["max"+e])?f["max"+e]:a;if(l<s&&l<a){s>a&&(s=a);for(var d=[],c=r[n.toLowerCase()],m=f.sensitivity.length-1;m>=0;m--){var y=f.sensitivity[m],h=f.speed[m];d.push({dir:-1,speed:h,position:g[o]+y}),d.push({dir:1,speed:h,position:g[i]-y-c});}u[e.toLowerCase()]={min:l,max:s,lines:d};}});}t.autoScroll=u.x||u.y?u:null;}function Ot(t){k.stop(),gt(t.options.handle,t.orgCursor),s.style.cursor=f,!1!==t.options.zIndex&&(t.elementStyle.zIndex=t.orgZIndex),g&&(s.style[g]=m);var e=i.default(t.element);G&&e.remove(G),N&&e.remove(N),a=null,z.cancel(),t.onDragEnd&&t.onDragEnd({left:t.elementBBox.left,top:t.elementBBox.top});}function Tt(t,e){return !t.disabled&&((!t.onDragStart||!1!==t.onDragStart(e))&&(a&&Ot(a),mt(t.options.handle),s.style.cursor=u||window.getComputedStyle(t.options.handle,"").cursor,!1!==t.options.zIndex&&(t.elementStyle.zIndex=t.options.zIndex),g&&(s.style[g]="none"),N&&i.default(t.element).add(N),a=t,l=!1,A.left=t.elementBBox.left-(e.clientX+window.pageXOffset),A.top=t.elementBBox.top-(e.clientY+window.pageYOffset),!0))}function Ct(t,e){var n,r=t.options;if(e.containment){var o=void 0;ot(e.containment)?e.containment!==r.containment&&(r.containment=e.containment,t.containmentIsBBox=!1,n=!0):(o=dt(nt(e.containment)))&&rt(o,r.containment)&&(r.containment=o,t.containmentIsBBox=!0,n=!0);}function i(t,e){function n(t){return "string"==typeof t?t.replace(/[, ]+/g," ").trim().toLowerCase():null}H(e.gravity)&&e.gravity>0&&(t.gravity=e.gravity);var r=n(e.corner);if(r){if("all"!==r){var o={},i=r.split(/\s/).reduce(function(t,e){return (e="tl"===(e=e.trim().replace(/^(.).*?-(.).*$/,"$1$2"))||"lt"===e?"tl":"tr"===e||"rt"===e?"tr":"bl"===e||"lb"===e?"bl":"br"===e||"rb"===e?"br":null)&&!o[e]&&(t.push(e),o[e]=!0),t},[]),a=i.length;r=a?4===a?"all":i.join(" "):null;}r&&(t.corner=r);}var l=n(e.side);l&&("start"===l||"end"===l||"both"===l?t.side=l:"start end"!==l&&"end start"!==l||(t.side="both")),"boolean"==typeof e.center&&(t.center=e.center);var s=n(e.edge);s&&("inside"===s||"outside"===s||"both"===s?t.edge=s:"inside outside"!==s&&"outside inside"!==s||(t.edge="both"));var d="string"==typeof e.base?e.base.trim().toLowerCase():null;return !d||"containment"!==d&&"document"!==d||(t.base=d),t}if(null!=e.snap){var l=F(e.snap)&&null!=e.snap.targets?e.snap:{targets:e.snap},s=[],d=i({targets:s},l);d.gravity||(d.gravity=b),d.corner||(d.corner=S),d.side||(d.side=w),"boolean"!=typeof d.center&&(d.center=!1),d.edge||(d.edge=E),d.base||(d.base=B);var u=(Array.isArray(l.targets)?l.targets:[l.targets]).reduce(function(t,e){if(null==e)return t;var n,r=ot(e),o=dt(nt(e)),a=r||o?{boundingBox:e}:F(e)&&null==e.start&&null==e.end&&null==e.step?e:{x:e,y:e},l=[],u={},f=a.boundingBox;if(r||ot(f))l.push({element:f}),u.boundingBox=f;else if(n=o||dt(nt(f)))l.push({ppBBox:n}),u.boundingBox=ut(n);else {var c,p=["x","y"].reduce(function(t,e){var n,r=a[e];if(n=at(r))t[e]=n,u[e]=lt(n);else {var o=void 0,i=void 0,l=void 0;F(r)&&(o=at(r.start),i=at(r.end),l=at(r.step),o&&i&&o.isRatio===i.isRatio&&o.value>=i.value&&(c=!0)),o=t[e+"Start"]=o||{value:0,isRatio:!1},i=t[e+"End"]=i||{value:1,isRatio:!0},u[e]={start:lt(o),end:lt(i)},l&&((l.isRatio?l.value>0:l.value>=2)?(t[e+"Step"]=l,u[e].step=lt(l)):c=!0);}return t},{});if(c)return t;p.xStart&&!p.xStep&&p.yStart&&!p.yStep?l.push({xStart:p.xStart,xEnd:p.xEnd,y:p.yStart},{xStart:p.xStart,xEnd:p.xEnd,y:p.yEnd},{x:p.xStart,yStart:p.yStart,yEnd:p.yEnd},{x:p.xEnd,yStart:p.yStart,yEnd:p.yEnd}):l.push(p);}if(l.length){s.push(i(u,a));var g=u.corner||d.corner,m=u.side||d.side,y=u.edge||d.edge,h={gravity:u.gravity||d.gravity,base:u.base||d.base,center:"boolean"==typeof u.center?u.center:d.center,corners:"all"===g?O:g.split(" "),sides:"both"===m?T:[m],edges:"both"===y?C:[y]};l.forEach(function(e){["gravity","corners","sides","center","edges","base"].forEach(function(t){e[t]=h[t];}),t.push(e);});}return t},[]);u.length&&(r.snap=d,rt(u,t.parsedSnapTargets)&&(t.parsedSnapTargets=u,n=!0));}else e.hasOwnProperty("snap")&&t.parsedSnapTargets&&(r.snap=t.parsedSnapTargets=t.snapTargets=void 0);if(e.autoScroll){var f=F(e.autoScroll)?e.autoScroll:{target:!0===e.autoScroll?window:e.autoScroll},c={};c.target=ot(f.target)?f.target:window,c.speed=[],(Array.isArray(f.speed)?f.speed:[f.speed]).every(function(t,e){return !!(e<=2&&H(t))&&(c.speed[e]=t,!0)}),c.speed.length||(c.speed=_);var p=Array.isArray(f.sensitivity)?f.sensitivity:[f.sensitivity];c.sensitivity=c.speed.map(function(t,e){return H(p[e])?p[e]:j[e]}),["X","Y"].forEach(function(t){var e="min"+t,n="max"+t;H(f[e])&&f[e]>=0&&(c[e]=f[e]),H(f[n])&&f[n]>=0&&(!c[e]||f[n]>=c[e])&&(c[n]=f[n]);}),rt(c,r.autoScroll)&&(r.autoScroll=c,n=!0);}else e.hasOwnProperty("autoScroll")&&(r.autoScroll&&(n=!0),r.autoScroll=void 0);if(n&&Bt(t),ot(e.handle)&&e.handle!==r.handle){r.handle&&(r.handle.style.cursor=t.orgCursor,g&&(r.handle.style[g]=t.orgUserSelect),z.removeStartHandler(r.handle,t.pointerEventHandlerId));var m=r.handle=e.handle;t.orgCursor=m.style.cursor,gt(m,t.orgCursor),g&&(t.orgUserSelect=m.style[g],m.style[g]="none"),z.addStartHandler(m,t.pointerEventHandlerId);}(H(e.zIndex)||!1===e.zIndex)&&(r.zIndex=e.zIndex,t===a&&(t.elementStyle.zIndex=!1===r.zIndex?t.orgZIndex:r.zIndex));var y,h={left:t.elementBBox.left,top:t.elementBBox.top};H(e.left)&&e.left!==h.left&&(h.left=e.left,y=!0),H(e.top)&&e.top!==h.top&&(h.top=e.top,y=!0),y&&bt(t,h),["onDrag","onMove","onDragStart","onMoveStart","onDragEnd"].forEach(function(n){"function"==typeof e[n]?(r[n]=e[n],t[n]=r[n].bind(t.ins)):e.hasOwnProperty(n)&&null==e[n]&&(r[n]=t[n]=void 0);});}k.move=function(t,e,n){Z.call(window,v),$(),y===t&&(e.x&&K.x&&(e.x.lastValue=K.x.lastValue),e.y&&K.y&&(e.y.lastValue=K.y.lastValue)),y=t,K=e,h=n;var r=Date.now();["x","y"].forEach(function(t){var e=K[t];e&&(e.lastFrameTime=r);}),v=U.call(window,J);},k.stop=function(){Z.call(window,v),$(),K={},y=null;};var _t=function(){function t(t,e){var n={ins:this,options:{zIndex:x},disabled:!1};if(Object.defineProperty(this,"_id",{value:++M}),n._id=this._id,R[this._id]=n,n.initArguments=Array.prototype.slice.call(arguments),!ot(t)||t===s)throw new Error("This element is not accepted.");if(e){if(!F(e))throw new Error("Invalid options.")}else e={};var o,a=!0;if(t instanceof SVGElement&&(o=t.ownerSVGElement)){if(!t.getBBox)throw new Error("This element is not accepted. (SVGLocatable)");if(!t.transform)throw new Error("This element is not accepted. (SVGAnimatedTransformList)");n.svgTransform=t.transform.baseVal.appendItem(o.createSVGTransform()),n.svgPoint=o.createSVGPoint();var l=t.nearestViewportElement;n.svgCtmElement=W?l.appendChild(document.createElementNS(o.namespaceURI,"rect")):l,a=!1,n.initElm=Et,n.moveElm=xt;}else {var d=r.default.getName("willChange");d&&(a=!1),!e.leftTop&&p?(d&&(t.style[d]="transform"),n.initElm=St,n.moveElm=ht):(d&&(t.style[d]="left, top"),n.initElm=wt,n.moveElm=vt);}if(n.element=pt(t,a),n.elementStyle=t.style,n.orgZIndex=n.elementStyle.zIndex,V&&i.default(t).add(V),n.pointerEventHandlerId=z.regStartHandler(function(t){return Tt(n,t)}),!e.containment){var u;e.containment=(u=t.parentNode)&&ot(u)?u:s;}e.handle||(e.handle=t),Ct(n,e);}return t.prototype.remove=function(){var t=R[this._id];this.disabled=!0,z.unregStartHandler(z.removeStartHandler(t.options.handle,t.pointerEventHandlerId)),delete R[this._id];},t.prototype.setOptions=function(t){return F(t)&&Ct(R[this._id],t),this},t.prototype.position=function(){return Bt(R[this._id]),this},Object.defineProperty(t.prototype,"disabled",{get:function(){return R[this._id].disabled},set:function(t){var e=R[this._id];(t=!!t)!==e.disabled&&(e.disabled=t,e.disabled?(e===a&&Ot(e),e.options.handle.style.cursor=e.orgCursor,g&&(e.options.handle.style[g]=e.orgUserSelect),V&&i.default(e.element).remove(V)):(gt(e.options.handle,e.orgCursor),g&&(e.options.handle.style[g]="none"),V&&i.default(e.element).add(V)));},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"element",{get:function(){return R[this._id].element},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"rect",{get:function(){return nt(R[this._id].elementBBox)},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"left",{get:function(){return R[this._id].elementBBox.left},set:function(t){Ct(R[this._id],{left:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"top",{get:function(){return R[this._id].elementBBox.top},set:function(t){Ct(R[this._id],{top:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"containment",{get:function(){var t=R[this._id];return t.containmentIsBBox?ut(t.options.containment):t.options.containment},set:function(t){Ct(R[this._id],{containment:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"snap",{get:function(){return nt(R[this._id].options.snap)},set:function(t){Ct(R[this._id],{snap:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"autoScroll",{get:function(){return nt(R[this._id].options.autoScroll)},set:function(t){Ct(R[this._id],{autoScroll:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"handle",{get:function(){return R[this._id].options.handle},set:function(t){Ct(R[this._id],{handle:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"zIndex",{get:function(){return R[this._id].options.zIndex},set:function(t){Ct(R[this._id],{zIndex:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"onDrag",{get:function(){return R[this._id].options.onDrag},set:function(t){Ct(R[this._id],{onDrag:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"onMove",{get:function(){return R[this._id].options.onMove},set:function(t){Ct(R[this._id],{onMove:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"onDragStart",{get:function(){return R[this._id].options.onDragStart},set:function(t){Ct(R[this._id],{onDragStart:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"onMoveStart",{get:function(){return R[this._id].options.onMoveStart},set:function(t){Ct(R[this._id],{onMoveStart:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"onDragEnd",{get:function(){return R[this._id].options.onDragEnd},set:function(t){Ct(R[this._id],{onDragEnd:t});},enumerable:!0,configurable:!0}),Object.defineProperty(t,"draggableCursor",{get:function(){return X},set:function(t){X!==t&&(X=t,d=null,Object.keys(R).forEach(function(t){var e=R[t];e.disabled||e===a&&!1!==u||(gt(e.options.handle,e.orgCursor),e===a&&(s.style.cursor=f,s.style.cursor=window.getComputedStyle(e.options.handle,"").cursor));}));},enumerable:!0,configurable:!0}),Object.defineProperty(t,"draggingCursor",{get:function(){return Y},set:function(t){Y!==t&&(Y=t,u=null,a&&(mt(a.options.handle),!1===u&&(gt(a.options.handle,a.orgCursor),s.style.cursor=f),s.style.cursor=u||window.getComputedStyle(a.options.handle,"").cursor));},enumerable:!0,configurable:!0}),Object.defineProperty(t,"draggableClass",{get:function(){return V},set:function(t){(t=t?t+"":void 0)!==V&&(Object.keys(R).forEach(function(e){var n=R[e];if(!n.disabled){var r=i.default(n.element);V&&r.remove(V),t&&r.add(t);}}),V=t);},enumerable:!0,configurable:!0}),Object.defineProperty(t,"draggingClass",{get:function(){return N},set:function(t){if((t=t?t+"":void 0)!==N){if(a){var e=i.default(a.element);N&&e.remove(N),t&&e.add(t);}N=t;}},enumerable:!0,configurable:!0}),Object.defineProperty(t,"movingClass",{get:function(){return G},set:function(t){if((t=t?t+"":void 0)!==G){if(a&&l){var e=i.default(a.element);G&&e.remove(G),t&&e.add(t);}G=t;}},enumerable:!0,configurable:!0}),t}();z.addMoveHandler(document,function(t){if(a){var e={left:t.clientX+window.pageXOffset+A.left,top:t.clientY+window.pageYOffset+A.top};if(bt(a,e,a.snapTargets?function(t){var e,n=a.snapTargets.length,r=!1,o=!1;for(e=0;e<n&&(!r||!o);e++){var i=a.snapTargets[e];(null==i.gravityXStart||t.left>=i.gravityXStart)&&(null==i.gravityXEnd||t.left<=i.gravityXEnd)&&(null==i.gravityYStart||t.top>=i.gravityYStart)&&(null==i.gravityYEnd||t.top<=i.gravityYEnd)&&(r||null==i.x||(t.left=i.x,r=!0,e=-1),o||null==i.y||(t.top=i.y,o=!0,e=-1));}return t.snapped=r||o,!a.onDrag||a.onDrag(t)}:a.onDrag)){var n={},r=a.autoScroll;if(r){var o={x:a.elementBBox.left-window.pageXOffset,y:a.elementBBox.top-window.pageYOffset};["x","y"].forEach(function(t){if(r[t]){var e=r[t].min,i=r[t].max;r[t].lines.some(function(r){return (-1===r.dir?o[t]<=r.position:o[t]>=r.position)&&(n[t]={dir:r.dir,speed:r.speed/1e3,min:e,max:i},!0)});}});}n.x||n.y?(k.move(r.target,n,r.isWindow?Q:tt),e.autoScroll=!0):k.stop(),l||(l=!0,G&&i.default(a.element).add(G),a.onMoveStart&&a.onMoveStart(e)),a.onMove&&a.onMove(e);}}});var jt=function(){a&&Ot(a);};z.addEndHandler(document,jt),z.addCancelHandler(document,jt);var It=function(){c=r.default.getName("transitionProperty"),p=r.default.getName("transform"),f=s.style.cursor,(g=r.default.getName("userSelect"))&&(m=s.style[g]);var t,e={};function n(t,e){t.initElm?Bt(t,e):(console.log("instance may have an error:"),console.log(t));}var i=!1,l=o.default.add(function(r){i||(i=!0,a&&(n(a,r.type),z.move(),e[a._id]=!0),clearTimeout(t),t=setTimeout(function(){var o;o=r.type,clearTimeout(t),Object.keys(R).forEach(function(t){e[t]||n(R[t],o);}),e={};},200),i=!1);});window.addEventListener("resize",l,!0),window.addEventListener("scroll",l,!0);};(s=document.body)?It():document.addEventListener("DOMContentLoaded",function(){s=document.body,It();},!0),exports.default=_t;
},{"pointer-event":"cjFF","cssprefix":"Fo6c","anim-event":"kohH","m-class-list":"O69e"}]},{},["tHsO"]);

});

const PlainDraggable = /*@__PURE__*/_commonjsHelpers.getDefaultExportFromCjs(plainDraggable_min);

const quickomDraggableCss = "quickom-draggable{}";

const QuickomDraggable = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.move = index.createEvent(this, "move", 7);
    this.moveStart = index.createEvent(this, "moveStart", 7);
    this.draggable = null;
    this.element = null;
  }
  async onRefDraggableEl(el) {
    this.element = el;
  }
  componentDidLoad() {
    let windowInnerWidth = Math.max(document.documentElement.clientWidth, window.innerWidth || 0);
    let windowInnerHeight = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
    let computedStyle = getComputedStyle(this.element);
    let right = +computedStyle.getPropertyValue('--widget-position-right').replace('px', '');
    let bottom = +computedStyle.getPropertyValue('--widget-position-bottom').replace('px', '');
    let top = +computedStyle.getPropertyValue('--widget-position-top').replace('px', '');
    let left = +computedStyle.getPropertyValue('--widget-position-left').replace('px', '');
    if (bottom) {
      top = windowInnerHeight - bottom - 60;
    }
    if (right) {
      left = windowInnerWidth - right - 60;
    }
    this.draggable = new PlainDraggable(this.element, {
      containment: window.document.body,
      left,
      top,
      onMoveStart: () => {
        this.moveStart.emit(this.draggable);
      },
      onMove: () => {
        this.move.emit(this.draggable);
      }
    });
  }
  render() {
    return (index.h("div", { ref: el => this.onRefDraggableEl(el), class: 'inline-block' }, index.h("slot", null)));
  }
};
QuickomDraggable.style = quickomDraggableCss;

exports.quickom_chat_iframe = QuickomChatIframe;
exports.quickom_draggable = QuickomDraggable;
